@@ -13,14 +13,30 @@ define([
 
 ], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS,
             api, config, constData, init) {
-    const { getImageUrl } = api;
+    const { GetImageUrl } = api;
     const { PROCESS_MODE } = config;
+    const { VP_CLASS_PREFIX
+        
+            , VP_CLASS_APIBLOCK_MAIN
+            , VP_CLASS_APIBLOCK_BOARD
+            , VP_CLASS_APIBLOCK_BUTTONS
+            , VP_CLASS_APIBLOCK_OPTION_TAB
+            , VP_CLASS_APIBLOCK_MENU_BTN
+            , VP_CLASS_APIBLOCK_CODELINE_ELLIPSIS
+
+            , STR_PARENT
+
+            , STR_WIDTH
+            , STR_MAX_WIDTH
+        
+            , API_BLOCK_HTML_URL_PATH
+            , API_BLOCK_INDEX_CSS } = constData;
 
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
         , funcName : "api_block"
-        , funcID : "JY1000"  // TODO: ID 규칙 생성 필요
+        , funcID : "api_block"  // TODO: ID 규칙 생성 필요
     }
 
     /**
@@ -31,7 +47,7 @@ define([
 
         // document.getElementsByTagName("head")[0].appendChild(link);
         // 컨테이너에서 전달된 callback 함수가 존재하면 실행.
-        if (typeof(callback) === 'function') {
+        if (typeof(callback) == 'function') {
             var uuid = vpCommon.getUUID();
             // 최대 10회 중복되지 않도록 체크
             for (var idx = 0; idx < 10; idx++) {
@@ -43,6 +59,7 @@ define([
             $(vpCommon.wrapSelector(`#${vpConst.OPTION_GREEN_ROOM}`)).find(`.${vpConst.API_OPTION_PAGE}`).addClass(uuid);
             // 옵션 객체 생성
             var ipImport = new ImportPackage(uuid);
+            ipImport.metadata = meta;
             // 옵션 속성 할당.
             ipImport.setOptionProp(funcOptProp);
             // html 설정.
@@ -54,9 +71,9 @@ define([
      * html 로드. 
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
     */
-    var initOption = function(callback) {
-        var htmlUrlPath  = "api_block/index.html";
-        vpCommon.loadHtml(vpCommon.wrapSelector(`#${vpConst.OPTION_GREEN_ROOM}`), htmlUrlPath, optionLoadCallback, callback);
+    var initOption = function(callback, meta) {
+        var htmlUrlPath  = API_BLOCK_HTML_URL_PATH;
+        vpCommon.loadHtml(vpCommon.wrapSelector(`#${vpConst.OPTION_GREEN_ROOM}`), htmlUrlPath, optionLoadCallback, callback, meta);
     }
 
     /**
@@ -66,6 +83,8 @@ define([
     var ImportPackage = function(uuid) {
         this.uuid = uuid; // Load html 영역의 uuid.
         this.blockContainer = null;
+        this.funcID = funcOptProp.funcID;
+        this.metadata = null;
     }
     /**
      * vpFuncJS 에서 상속
@@ -84,30 +103,30 @@ define([
      * html 내부 binding 처리
      */
     ImportPackage.prototype.initHtml = function() {
-        var that = this;
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "api_block/index.css");
+        // var that = this;
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + API_BLOCK_INDEX_CSS);
         this.blockContainer = init();
         this.blockContainer.setImportPackageThis(this);
+        this.blockContainer.setAPIBlockMetadataHandler();
+
+        if (this.metadata) {
+            // console.log('metadata 있음');
+            this.blockContainer.loadAPIBlockMetadata(this.metadata);
+        } else {
+            // console.log('metadata 없음 -> 새로 만듬', this.metadata);
+            this.blockContainer.setAPIBlockMetadata();
+        }
+  
 
         /** API Block 화면 좌우로 resize 할 경우 option page width 계산 */
         $( window ).resize( function() {
-            // this.blockContainer.resizeScreen();
-            var vpNodeEditorMainRect = $('.vp-nodeeditor-main')[0].getBoundingClientRect();
-            var vpNodeEditorLeftRect = $('.vp-nodeeditor-left')[0].getBoundingClientRect();
-            var vpNodeEditorRightRect = $('.vp-nodeeditor-right')[0].getBoundingClientRect();
-    
-            var vpNodeEditorOptionTabWidth = vpNodeEditorMainRect.width - vpNodeEditorLeftRect.width - vpNodeEditorRightRect.width;
-            $('.vp-nodeeditor-option-tab').css('width', vpNodeEditorOptionTabWidth);
-            $('.vp-nodeeditor-codeline-ellipsis').css('max-width', vpNodeEditorLeftRect.width - 180 );
-
-        });
-        $(".vp-nodeeditor-left").resizable({
-            containment: 'parent',
-            handles: 'e',
-            resizeHeight: false
-            ,resize:(function() {
-              
-            })
+            var optionPageRect = $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB))[0].getBoundingClientRect();
+            var optionPageRectWidth = optionPageRect.width; 
+     
+            $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css('right', 0);
+            $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_OPTION_TAB)).css('left', 'initial');
+      
+            $(vpCommon.wrapSelector(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_MENU_BTN)).css('right', optionPageRectWidth + 5);
         });
 
     }
@@ -137,13 +156,23 @@ define([
         } else {
             result = this.blockContainer.makeCode();
         }
-
-        if ( !addCell ) {
-            return result;
+        
+        if (this.blockContainer.getBlockList().length == 0) {
+            return;
         }
 
+        /** add code */
+        if ( !addCell ) {
+            // code add시 메타데이터 생성
+            this.blockContainer.saveAPIBlockMetadata();
+            return result;
+        }
+        
         // execute code
         this.cellExecute(result, exec);
+
+        // code run시 메타데이터 생성
+        this.blockContainer.saveAPIBlockMetadata();
     }
 
     return {
