@@ -22,6 +22,7 @@ define([
         this._caption = caption;
         this._isOpen = open;
         this._uniqueness = uniqueness;
+        this._additionalClass = "";
         this._attributes = "";
     };
 
@@ -69,7 +70,6 @@ define([
      */
     vpAccordionBox.prototype.setOpenBox = function(open = false) {
         this._isOpen = open;
-        this._uniqueness = uniqueness;
     }
 
     /**
@@ -80,6 +80,21 @@ define([
         this._uniqueness = uniqueness;
     }
 
+    /**
+     * 추가 클래스 설정
+     * @param {String} additionalClass 추가 클래스
+     */
+    vpAccordionBox.prototype.addClass = function(additionalClass = "") {
+        if (additionalClass == "") return;
+        var that = this;
+        that._additionalClass = vpCommon.formatString("{0} {1}", that._additionalClass, additionalClass);
+    }
+    
+    /**
+     * 추가 속성 부여
+     * @param {String} attrName 속성명
+     * @param {String} attrValue 속성값
+     */
     vpAccordionBox.prototype.addAttribute = function(attrName = "", attrValue = "") {
         if (attrName == "") return;
         var that = this;
@@ -94,8 +109,8 @@ define([
         var sbTagString = new sb.StringBuilder();
         var that = this;
 
-        sbTagString.appendFormatLine("<div class='{0} {1} {2} {3}' {4}>"
-            , that._UUID, vpConst.ACCORDION_CONTAINER, that._isOpen ? vpConst.ACCORDION_OPEN_CLASS : "", that._uniqueness ? "uniqueType" : "", that._attributes ? that._attributes : "");
+        sbTagString.appendFormatLine("<div class='{0} {1} {2} {3} {4}' {5}>"
+            , that._UUID, vpConst.ACCORDION_CONTAINER, that._isOpen ? vpConst.ACCORDION_OPEN_CLASS : "", that._uniqueness ? "uniqueType" : "", that._additionalClass, that._attributes);
 
         sbTagString.appendFormatLine("<div class='{0}'>", vpConst.ACCORDION_HEADER);
         sbTagString.appendFormatLine("<span class='{0}{1}'></span>", vpConst.VP_CLASS_PREFIX, "accordion-indicator");
