@@ -1,7 +1,8 @@
 define([
     'require'
     , 'jquery'
-], function (requirejs, $) {
+    , 'nbextensions/visualpython/src/common/constant'
+], function (requirejs, $, vpConst) {
     "use strict";
 
     /**
@@ -27,8 +28,8 @@ define([
         // xml 함수 id
         this.funcID = funcID;
 
-        this.prefixSelector = '#vp_prefixBox textarea';
-        this.postfixSelector = '#vp_postfixBox textarea';
+        this.prefixSelector = '#' + vpConst.API_OPTION_PREFIX_CODE_ID; //'#vp_prefixBox textarea';
+        this.postfixSelector = '#' + vpConst.API_OPTION_POSTFIX_CODE_ID; //'#vp_postfixBox textarea';
     };
 
     /**
@@ -170,7 +171,6 @@ define([
         // set options
         metadata.options && metadata.options.forEach(opt => {
             var tag = $(pageThis.wrapSelector('#' + opt.id));
-            console.log($(tag), opt.value);
             // var tagType = tag.prop('tagName');
             tag.val(opt.value);
         })
