@@ -12,12 +12,12 @@ define([
      * @param {String} prefix html url 앞부분 명시가능(생략 가능)
      * @param {function} callback callback 함수
      * @param {function} recursiveCallback callback 의 callback
+     * @param {object} callbackParam callback 사용 추가 파라미터
      */
-    var loadHtml = function(destSelector, url, prefix, callback, recursiveCallback) {
-        // console.log("url : " + url);
-        // console.log("prefix : " + prefix);
+    var loadHtml = function(destSelector, url, prefix, callback, recursiveCallback, callbackParam) {
         // prefix 없이 callback 전달된 경우 처리
         if (typeof(prefix) === 'function') {
+            callbackParam = recursiveCallback;
             recursiveCallback = callback;
             callback = prefix;
             prefix = null;
@@ -40,7 +40,7 @@ define([
             } else {
                 // callback 이 함수이면 실행
                 if (typeof(callback) === 'function')
-                    callback(recursiveCallback);
+                    callback(recursiveCallback, callbackParam);
             }
         });
     }
@@ -80,7 +80,7 @@ define([
      * @param {String} selector 제한할 대상 선택자. 복수 매개 시 순서대로 제한됨
      * @returns wraped selecotr 
      */
-    var wrapSelector = function(selector) {
+    var wrapSelector = function(selector = "") {
         var sbSelector = new sb.StringBuilder();
         var cnt = arguments.length;
         // 추가 제한자가 없는 경우
@@ -177,9 +177,9 @@ define([
                 // bind 이벤트 함수
 
                 // alertModal창 메세지 출력
-                $('.alertModal-titleStr').html(titleStr);
+                $('.vp-alertModal-titleStr').html(titleStr);
                 // alertModal창 확인 버튼 누를시
-                $('.alertModal-yes').click( function() {
+                $('.vp-alertModal-yes').click( function() {
                     $('body').find('#vp_alertModal').remove();
                     // 종료후 head 태그에 import된 alertModal.css와 alertModal.html을 삭제함
                     removeHeadScript("alertModal");
@@ -214,7 +214,7 @@ define([
         var loadURL = Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.SOURCE_PATH + "component/successMessage.html";
         $(`<div id="vp_successMessage"></div>`)
             .load(loadURL, function() {
-                $('.materialert').append(`<div>${titleStr}</div>`);
+                $('.vp-successMessage').append(`<div>${titleStr}</div>`);
                 // 한 번 비동기 실행 다음 3초 후  종료
                 setTimeout( function() {
                     $("#vp_successMessage").remove();
