@@ -8,7 +8,8 @@ define([
     , 'nbextensions/visualpython/src/pandas/common/commonPandas'
     , 'nbextensions/visualpython/src/pandas/common/pandasGenerator'
     , 'nbextensions/visualpython/src/common/vpBoard'
-], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, pdGen, VpBoard) {
+    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
+], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, pdGen, VpBoard, vpSuggestInputText) {
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
@@ -94,10 +95,11 @@ define([
         this.package = {
             input: [
                 { name: 'vp_varList' },
-                { name: 'vp_colList' },
-                { name: 'vp_idxList' },
+                { name: 'vp_colMeta' },
+                { name: 'vp_returnType' },
                 { name: 'vp_varApiSearch' },
-                { name: 'vp_varApiFuncId' }
+                { name: 'vp_varApiFuncId' },
+                { name: 'vp_returnVariable' }
             ]
         }
 
@@ -203,6 +205,48 @@ define([
         // vpFuncJS.VpFuncJS.prototype.optionValidation.apply(this);
     }
 
+    VariablePackage.prototype.getMetadata = function(id) {
+        if (this.metadata == undefined)
+            return "";
+        var len = this.metadata.options.length;
+        for (var i = 0; i < len; i++) {
+            var obj = this.metadata.options[i];
+            if (obj.id == id)
+                return obj.value;
+        }
+        return "";
+    }
+
+    VariablePackage.prototype.getMetaLoaded = function(id) {
+        if (this.metadata == undefined)
+            return true;
+
+        var result = true;
+        var len = this.metadata.options.length;
+        for (var i = 0; i < len; i++) {
+            var obj = this.metadata.options[i];
+            if (obj.id == id)
+            {
+                if (obj.metaLoaded != true) {
+                    result = false;
+                }
+                break;
+            }
+        }
+        return result;
+    }
+
+    VariablePackage.prototype.checkMetaLoaded = function(id) {
+        if (this.metadata == undefined)
+            return true;
+        var len = this.metadata.options.length;
+        for (var i = 0; i < len; i++) {
+            if (this.metadata.options[i].id == id) {
+                this.metadata['options'][i]['metaLoaded'] = true;
+            }
+        }
+        return true;
+    }
 
     /**
      * html 내부 binding 처리
@@ -210,18 +254,127 @@ define([
     VariablePackage.prototype.initHtml = function() {
         var that = this;
 
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/board.css");
+
         this.showFunctionTitle();
 
+        // load variables (async)
         this.loadVariables();
 
+        // hide del-col button & connect operator tag as default
         $(this.wrapSelector('.vp-oper-connect')).hide();
-        $(this.wrapSelector('.vp-del-col')).hide();
+        // $(this.wrapSelector('.vp-del-col')).hide();
 
         // 변수이름 클릭 시
         $(this.wrapSelector('#vp_varList')).change(function() {
             that.handleVariableSelection();
+
+            var varType = $(that.wrapSelector('#vp_varList')).find(':selected').data('var-type');
+            // set return type
+            $(that.wrapSelector('#vp_returnType')).val(varType);
+
+            // clear api search
+            $(that.wrapSelector('#vp_varApiSearch')).val('');
+            $(that.wrapSelector('#vp_varApiFuncId')).val('');
+
+            // load API List for selected variable
+            that.loadApiList();
         });
 
+        // view button click - view little popup to show variable & details
+        $(this.wrapSelector('#vp_varView')).click(function(event) {
+            // set position
+            var boxSize = { width: 350, height: 200 };
+            var boxPosition = { position: 'fixed', left: event.pageX - 20, top: event.pageY + 20 };
+            if (event.pageX + boxSize.width > window.innerWidth) {
+                boxPosition.left = event.pageX - boxSize.width;
+            }
+            if (event.pageY + boxSize.height > window.innerHeight) {
+                boxPosition.top = event.pageY - boxSize.height - 20;
+            }
+            $('#vp_varViewBox').css({
+                ...boxPosition
+            });
+
+            // show/hide popup area
+            $(that.wrapSelector('#vp_varViewBox')).toggle();
+            
+        });
+        // view close button click
+        $(this.wrapSelector('.vp-close-view')).click(function(event) {
+            // hide view
+            // show/hide popup area
+            $(that.wrapSelector('#vp_varViewBox')).toggle();
+        });
+
+        // view object selection
+        $(document).on('click', this.wrapSelector('.vp-var-view-item'), function(event) {
+            // set selection style
+            // TODO: attach .selected
+            $(that.wrapSelector('.vp-var-view-item')).removeClass('selected');
+            $(this).addClass('selected');
+
+            var varName = $(this).find('td:first').text();
+            var varType = $(this).find('td:last').text();
+
+            // dataframe : columns, dtypes, array
+            // series : array
+            // use json.dumps to make python dict/list to become parsable with javascript JSON
+            var code = new sb.StringBuilder();
+            code.appendLine('import json');
+            if (varType == 'DataFrame') {
+                code.append(`print(json.dumps([ { "colName": c, "dtype": str(${varName}[c].dtype), "array": str(${varName}[c].array) } for c in list(${varName}.columns) ]))`);
+            } else if (varType == 'Series') {
+                code.append(`print(json.dumps({"dtype": str(${varName}.dtype), "array": str(${varName}.array) }))`);
+            }
+
+            // get result and show on detail box
+            that.kernelExecute(code.toString(), function(result) {
+                var varResult = JSON.parse(result);
+
+                $(that.wrapSelector('#vp_varDetailColList')).html('');
+                // DataFrame / Series Detail
+                if (varType == 'DataFrame') {
+                    if (varResult.length > 0) {
+                        varResult.forEach(v => {
+                            var option = $(`<option value="${v.colName}" data-dtype="${v.dtype}" data-array="${v.array}">${v.colName}</option>`)
+                            $(that.wrapSelector('#vp_varDetailColList')).append(option);
+                        });
+
+                        $(that.wrapSelector('#vp_varDetailDtype')).text(varResult[0].dtype);
+
+                        var array = varResult[0].array.replaceAll('/n', '\n');
+                        $(that.wrapSelector('#vp_varDetailArray')).text(array);
+                    }
+
+                    // show columns
+                    // $(that.wrapSelector('#vp_varDetailColList')).closest('tr').show();
+                    $(that.wrapSelector('#vp_varDetailColList')).attr({'disabled': false});
+                } else if (varType == 'Series') {
+                    $(that.wrapSelector('#vp_varDetailDtype')).text(varResult.dtype);
+                    var array = varResult.array.replaceAll('/n', '\n');
+                    $(that.wrapSelector('#vp_varDetailArray')).text(array);
+
+                    // disable columns
+                    $(that.wrapSelector('#vp_varDetailColList')).attr({'disabled': true});
+                }
+
+            });
+        });
+
+        // view column selection
+        $(this.wrapSelector('#vp_varDetailColList')).change(function() {
+            var dtype = $(that.wrapSelector('#vp_varDetailColList')).find(':selected').data('dtype');
+            var array = $(that.wrapSelector('#vp_varDetailColList')).find(':selected').data('array');
+
+            $(that.wrapSelector('#vp_varDetailDtype')).text(dtype);
+
+            array = array.replaceAll('/n', '\n');
+            $(that.wrapSelector('#vp_varDetailArray')).text(array);
+        });
+        
+
         // load variables on refresh
         $(this.wrapSelector('#vp_varRefresh')).click(function(event) {
             event.stopPropagation();
@@ -231,8 +384,54 @@ define([
         });
 
         // column selection
-        $(document).on('click', this.wrapSelector('.vp-col-list'), function() {
+        $(document).on('change', this.wrapSelector('.vp-col-list'), function() {
             that.replaceBoard();
+
+            var objName = $(that.wrapSelector('#vp_varList')).val();
+            var colName = $(this).val();
+            var colDtype = $(this).find(':selected').data('dtype');
+            var conditionTag = $(this).closest('td').find('.vp-condition');
+
+            console.log(objName, colName, colDtype, conditionTag);
+
+            if (colDtype == 'object') {
+                // search column unique values
+                var code = new sb.StringBuilder();
+                code.appendLine('import json');
+                code.appendFormatLine('_vpcoluniq = {0}[{1}].unique()', objName, convertToStr(colName));
+                code.appendLine('_vpcoluniq.sort()');
+                code.append('print(json.dumps(list(_vpcoluniq)))');
+                console.log(code.toString())
+                that.kernelExecute(code.toString(), function(result) {
+                    var varResult = JSON.parse(result);
+                    
+                    if (varResult != undefined && varResult.length > 0) {
+                        // conditions using suggestInput
+                        var suggestInput = new vpSuggestInputText.vpSuggestInputText();
+                        suggestInput.addClass('vp-input m');
+                        suggestInput.addClass('vp-condition');
+                        suggestInput.setPlaceholder("categorical dtype");
+                        suggestInput.setSuggestList(function() { return varResult; });
+                        suggestInput.setNormalFilter(false);
+                        $(conditionTag).replaceWith(function() {
+                            return suggestInput.toTagString();
+                        });
+                    }
+                });
+            } else {
+                // condition reset using suggestInput
+                var suggestInput = new vpSuggestInputText.vpSuggestInputText();
+                suggestInput.addClass('vp-input m');
+                suggestInput.addClass('vp-condition');
+                if (colDtype != undefined) {
+                    suggestInput.setPlaceholder(colDtype + " dtype");
+                }
+                suggestInput.setNormalFilter(false);
+                $(conditionTag).replaceWith(function() {
+                    return suggestInput.toTagString();
+                });
+            }
+
         });
         // operator selection
         $(document).on('click', this.wrapSelector('.vp-oper-list'), function() {
@@ -256,6 +455,7 @@ define([
             var clone = $(that.wrapSelector('#vp_colList tr:first')).clone();
 
             clone.find('input').val('');
+            clone.find('.vp-condition').attr({'placeholder': ''});
             // hide last connect operator
             clone.find('.vp-oper-connect').hide();
             // show connect operator right before last one
@@ -263,17 +463,29 @@ define([
             clone.insertBefore('#vp_colList tr:last');
 
             // show delete button
-            $(that.wrapSelector('#vp_colList tr td .vp-del-col')).show();
+            // $(that.wrapSelector('#vp_colList tr td .vp-del-col')).show();
         });
         // on column delete
         $(document).on("click", this.wrapSelector('.vp-del-col'), function(event) {
             event.stopPropagation();
-            $(this).parent().parent().remove();
-            $(that.wrapSelector('#vp_colList .vp-oper-connect:last')).hide();
-
+            
             var colList = $(that.wrapSelector('#vp_colList tr td:not(:last)'));
             if (colList.length <= 1) {
-                colList.find('.vp-del-col').hide();
+                // clear
+                $(that.wrapSelector('.vp-col-list')).val('');
+                $(that.wrapSelector('.vp-oper-list')).val('');
+                $(that.wrapSelector('.vp-condition')).val('');
+                $(that.wrapSelector('.vp-condition')).attr({ 'placeholder': '' });
+                $(that.wrapSelector('.vp-oper-connect')).val('');
+            } else {
+                $(this).parent().parent().remove();
+                $(that.wrapSelector('#vp_colList .vp-oper-connect:last')).hide();
+
+                if (colList.length == 2) {
+                    if ($(that.wrapSelector('.vp-col-list')).val() != '') {
+                        $(that.wrapSelector('#vp_returnType')).attr('disabled', false);
+                    }
+                }
             }
 
             that.replaceBoard();
@@ -281,12 +493,25 @@ define([
 
         // on return type change
         $(this.wrapSelector('#vp_returnType')).change(function() {
+            that.replaceBoard();
+
+            $(that.wrapSelector('#vp_varApiSearch')).val('');
+            $(that.wrapSelector('#vp_varApiFuncId')).val('');
+
             // load API List for selected variable
             that.loadApiList();
         });
 
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/board.css");
+        // close variable selector
+        $('body').on('click', function(evt) {
+            // plot select box 닫기
+            if (evt.target.id != vpConst.VP_PLOT_SELECT_BOX_ID
+                && evt.target.id != 'vp_varView') {
+                if ($(evt.target).parents('#' + vpConst.VP_PLOT_SELECT_BOX_ID).length <= 0) {
+                    $(that.wrapSelector('#' + vpConst.VP_PLOT_SELECT_BOX_ID)).hide();
+                }
+            }
+        }); 
     }
 
     var convertToStr = function(code) {
@@ -307,17 +532,21 @@ define([
 
         var varType = $(this.wrapSelector('#vp_varList')).find(':selected').attr('data-var-type');
 
-        var returnType = $(this.wrapSelector('#vp_returnType')).val();
         var apiCode = $(this.wrapSelector('#vp_varApiSearch')).val();
 
-        // TODO: add block to board with condition
-        // - type: var / type: api(if apiCode is not undefined)
-        // - with col/idx or not
-        // - api                = df.api
-        // - col + api          = df[[col]].api
-        // - col                = df[col]
-        // - col + dataframe    = df[[col]] //FIXME:
-        // - idx                = df.iloc[idx] / df.loc[idx]
+        /**
+         * Add block to board with condition
+         * - type: var / api
+         * - columns : column / condition(column + operator)
+         * - return type : if last bracket has only one column - DataFrame/Series selectable
+         *               / else - its datatype
+         * - cases :
+         *  1) df[col] / df[[col]] / df[[col1, col2]]
+         *  2) df[condition] / df[condition1 & condition2]
+         *  3) df[condition][col] / df[condition][[col]]
+         *  4) df[[col]][condition]
+         *  5) s
+         */
 
         // vpBoard add
         var blocks = [
@@ -326,9 +555,10 @@ define([
 
         // columns + condition block
         var colList = $(this.wrapSelector('#vp_colList tr td:not(:last)'));
+        var colMeta = []; // metadata for column list
         
-        var colSelector = [];
-        var condSelector = [];
+        var colSelector = [];   // temporary column list 
+        var condSelector = [];  // temporary condition list
         for (var i = 0; i < colList.length; i++) {
             var colTag = $(colList[i]);
             var colName = colTag.find('.vp-col-list').val();
@@ -336,19 +566,32 @@ define([
             var cond = colTag.find('.vp-condition').val();
             var connector = i > 0? $(colList[i- 1]).find('.vp-oper-connect').val() : undefined;
 
+            // if no column selected, pass
             if (colName == "") continue;
 
+            // save metadata for column list
+            colMeta.push({
+                'vp-col-list': colName,
+                'vp-oper-list': oper,
+                'vp-condition': cond,
+                'vp-oper-connect': $(colList[i]).find('.vp-oper-connect').val()
+            });
+
+            // if operator selected, condition / else column
             if (oper == '') {
+                // column 
+                // add blocks with last temp condition list
                 if (condSelector.length > 0) {
+                    // block result : [condition1, condition2]
                     var idx = blocks.length;
                     blocks = blocks.concat(condSelector);
                     var lastIdx = blocks.length - 1;
-                    // TODO: [] 추가
+                    // [] 추가
                     blocks.push({
                         code: '[]', type: 'brac', child: lastIdx
                     });
 
-                    // TODO: idx 연결
+                    // idx 연결
                     blocks[idx - 1]['next'] = blocks.length - 1;
 
                     condSelector = [];
@@ -356,9 +599,10 @@ define([
                 // column selector
                 colSelector.push(colName);
             } else {
-                // TODO: 조건식도 호환되도록 해야함
                 // condition selector
+                // add blocks with last temp column list
                 if (colSelector.length > 0) {
+                    // block result : [[code1, code2]] / [[col]]
                     var idx = blocks.length;
                     blocks[idx - 1]['next'] = idx + 2;
                     blocks.push({
@@ -397,37 +641,71 @@ define([
             }
         }
 
-        if (colSelector.length > 0) {
-            var idx = blocks.length;
-            blocks[idx - 1]['next'] = idx + 2;
-            blocks.push({
-                code: colSelector.map(v => convertToStr(v)).toString(),
-                type: 'code'
-            });
-            blocks.push({
-                code: '[]', type: 'brac', child: idx
-            });
-            blocks.push({
-                code: '[]', type: 'brac', child: idx + 1
-            });
-        }
         if (condSelector.length > 0) {
             var idx = blocks.length;
             blocks = blocks.concat(condSelector);
             var lastIdx = blocks.length - 1;
-            // TODO: [] 추가
+            // [] 추가
             blocks.push({
                 code: '[]', type: 'brac', child: lastIdx
             });
 
-            // TODO: idx 연결
+            // idx 연결
             blocks[idx - 1]['next'] = blocks.length - 1;
 
             condSelector = [];
+
+            // only same as datatype
+            $(this.wrapSelector('#vp_returnType')).val(varType);
+            $(this.wrapSelector('#vp_returnType')).attr('disabled', true);
+            // load API List for selected variable
+            this.loadApiList();
+        } else {
+            // set return type depends on last columns
+            if (colSelector.length != 1) {
+                // only dataframe
+                $(this.wrapSelector('#vp_returnType')).val(varType);
+                $(this.wrapSelector('#vp_returnType')).attr('disabled', true);
+                // load API List for selected variable
+                this.loadApiList();
+            } else {
+                // allow dataframe/series selection
+                $(this.wrapSelector('#vp_returnType')).attr('disabled', false);
+            }
+
+            var returnType = $(this.wrapSelector('#vp_returnType')).val();
+            if (colSelector.length > 0) {
+                if (returnType == 'DataFrame') {
+                    // with double brackets
+                    var idx = blocks.length;
+                    blocks[idx - 1]['next'] = idx + 2;
+                    blocks.push({
+                        code: colSelector.map(v => convertToStr(v)).toString(),
+                        type: 'code'
+                    });
+                    blocks.push({
+                        code: '[]', type: 'brac', child: idx
+                    });
+                    blocks.push({
+                        code: '[]', type: 'brac', child: idx + 1
+                    });
+                } else if (returnType == 'Series') {
+                    // with single bracket
+                    var idx = blocks.length;
+                    blocks[idx - 1]['next'] = idx + 1;
+                    blocks.push({
+                        code: colSelector.map(v => convertToStr(v)).toString(),
+                        type: 'code'
+                    });
+                    blocks.push({
+                        code: '[]', type: 'brac', child: idx
+                    });
+                }
+            }
+            
         }
 
         // api list attach
-        // TODO: API 리스트도 returnType에 맞춰서 연결
         if (apiCode != undefined && apiCode != '') {
             blocks[blocks.length -1]['next'] = blocks.length;
             blocks.push({
@@ -435,7 +713,8 @@ define([
             })
         }
 
-        console.log(blocks);
+        // save column metadata
+        $(this.wrapSelector('#vp_colMeta')).val(encodeURIComponent(JSON.stringify(colMeta)));
 
         return blocks;
     }
@@ -443,19 +722,7 @@ define([
     /**
      * initialize options
      */
-    VariablePackage.prototype.initOptions = function() {
-        // init before loadVariable
-        // initialize tags
-        // $(this.wrapSelector('#vp_varList')).html('');
-
-        // // init before bind selection event
-        // // initialize : hide options
-        // $(this.wrapSelector('#vp_colList')).closest('tr').hide();
-        // $(this.wrapSelector('#vp_idxList')).closest('tr').hide();
-
-        // // init api list
-        // $(this.wrapSelector('#vp_varApiList')).html('<ul class="vp-var-api-list"></ul>');
-
+    VariablePackage.prototype.initOptions = function(loadMeta = false) {
         var that = this;
 
         // show api list
@@ -474,8 +741,16 @@ define([
             }
         });
 
-        $(this.wrapSelector('#vp_varApiSearch')).val('');
-        $(this.wrapSelector('#vp_varApiFuncId')).val('');
+        if (loadMeta) {
+            // load other metadata
+            $(this.wrapSelector('#vp_returnType')).val(this.getMetadata('vp_returnType'));
+            $(this.wrapSelector('#vp_apiSearch')).val(this.getMetadata('vp_apiSearch'));
+            this.checkMetaLoaded('vp_returnType');
+            this.checkMetaLoaded('vp_apiSearch');
+        } else {
+            $(this.wrapSelector('#vp_varApiSearch')).val('');
+            $(this.wrapSelector('#vp_varApiFuncId')).val('');
+        }
 
         // bind event for variable selection
         this.handleVariableSelection();
@@ -497,37 +772,78 @@ define([
     VariablePackage.prototype.loadVariables = function() {
         var that = this;
 
+        // save selectedVariable
+        var selectedVariable = $(this.wrapSelector('#vp_varList')).val();
+        var metaLoaded = this.getMetaLoaded('vp_varList');
+        if (metaLoaded == false) {
+            var metaVariable = this.getMetadata('vp_varList'); //that.metadata.options[0].value;
+            selectedVariable = metaVariable;
+            this.checkMetaLoaded('vp_varList');
+        }
+
         // 조회가능한 변수 data type 정의 FIXME: 조회 필요한 변수 유형 추가
         var types = _SEARCHABLE_DATA_TYPES;
 
+        // 변수목록 select tag 초기화
         var tagVarList = this.wrapSelector('#vp_varList');
         $(tagVarList).html('');
+
+        // View 초기화
+        var viewList = $(this.wrapSelector('#vp_varViewList tbody'));
+        $(viewList).html('');
         
         // HTML 구성
         pdGen.vp_searchVarList(types, function(result) {
             var jsonVars = result.replace(/'/gi, `"`);
             var varList = JSON.parse(jsonVars);
 
+            var hasVariable = false;
             // 변수목록 추가
             varList.forEach(varObj => {
                 if (types.includes(varObj.varType) && varObj.varName[0] !== '_') {
-                    var tagOption = document.createElement('option');
-                    $(tagOption).attr({
+                    var varAttr = {
                         'data-var-name': varObj.varName,
                         'data-var-type': varObj.varType,
                         'value': varObj.varName
-                    });
-                    tagOption.innerText = `${varObj.varName} (${varObj.varType})`;
+                    };
+
+                    // 변수목록에 option tag로 추가
+                    var tagOption = document.createElement('option');
+                    $(tagOption).attr(varAttr);
+                    tagOption.innerText = `${varObj.varName}`;
 
                     $(tagVarList).append(tagOption);
+
+                    // View Table에 추가
+                    var tagRow = $(`<tr class="vp-var-view-item"><td>${varObj.varName}</td><td>${varObj.varType}</td></tr>`);
+                    $(viewList).append(tagRow);
+
+                    if (varObj.varName == selectedVariable) {
+                        hasVariable = true;
+                    }
                 }
             });
 
-            that.initOptions();
+            if (metaLoaded == false && hasVariable) {
+                $(tagVarList).val(selectedVariable);
+                that.initOptions(true);
+            } else {
+                if (!hasVariable) {
+                    // first load
+                    that.initOptions();
+                } else {
+                    // leave variable selected
+                    $(tagVarList).val(selectedVariable);
+                }
+            }
 
         });
     };
 
+    /**
+     * refresh and replace board with current information
+     * - variable + columns/conditions + return type + api
+     */
     VariablePackage.prototype.replaceBoard = function() {
         // clear board
         vpBoard.clear();
@@ -546,6 +862,21 @@ define([
 
         // initialize on event : hide options
         $(this.wrapSelector('#vp_colList')).closest('tr').hide();
+        // initialize column list
+        var clone = $(this.wrapSelector('#vp_colList tr:first')).clone();
+        clone.find('input').val('');
+        clone.find('.vp-condition').attr({'placeholder': ''});
+        // hide last connect operator
+        clone.find('.vp-oper-connect').hide();
+        // hide delete button
+        // clone.find('.vp-del-col').hide();
+
+
+        // show DataType as information
+        $(this.wrapSelector('#vp_varDataType')).text(varType);
+
+        $(this.wrapSelector('#vp_colList tr:not(:last)')).remove();
+        $(this.wrapSelector('#vp_colList')).prepend(clone);
 
         // Pandas Objects
         // if pandas object
@@ -554,18 +885,16 @@ define([
             this.getObjectDetail(varName, 'columns', '.vp-col-list');
 
             $(this.wrapSelector('#vp_colList')).closest('tr').show();
-        } else {
+
+            $(this.wrapSelector('#vp_returnType')).attr('disabled', false);
+
+        } else if (varType == 'Series') {
             // series
             // replace board with now status of board option
             this.replaceBoard();
+
+            $(this.wrapSelector('#vp_returnType')).attr('disabled', true);
         }
-
-        // set return type
-        $(this.wrapSelector('#vp_returnType')).val(varType);
-        // load API List for selected variable
-        this.loadApiList();
-
-        
     };
 
     /**
@@ -577,17 +906,49 @@ define([
     VariablePackage.prototype.getObjectDetail = function(varName, property, selectId) {
         var that = this;
         // 변수 col, idx 정보 조회 command, callback
-        var command = `print(list(${varName}.${property}))`;
-        this.kernelExecute(command, function(result) {
-            var jsonVars = result.replace(/'/gi, `"`);
-            var varList = JSON.parse(jsonVars);
+        var command = new sb.StringBuilder();
+        command.appendLine('import json');
+        command.append('print(json.dumps([ { "value": c ')
+        if (property == 'columns') {
+            command.appendFormat(', "dtype": str({0}[c].dtype)', varName);
+        }
+        command.appendFormat('} for c in {0}.{1} ]))', varName, property);
+        this.kernelExecute(command.toString(), function(result) {
+            var varList = JSON.parse(result);
 
-            var optVar = '<option value=""></option>';
+            var optVar = new sb.StringBuilder();
+            optVar.appendLine('<option value=""></option>');
             varList.forEach(obj => {
-                optVar += `<option value="${obj}">${obj}</option>`;
+                optVar.appendFormat('<option value="{0}"', obj.value);
+                if (property == 'columns') {
+                    optVar.appendFormat(' data-dtype="{0}"', obj.dtype)
+                }
+                optVar.appendFormatLine('>{0}</option>', obj.value);
             });
 
-            $(that.wrapSelector(selectId)).html(optVar);
+            $(that.wrapSelector(selectId)).html(optVar.toString());
+
+            // if first time loading, set with metadata
+            if (that.getMetaLoaded('vp_colMeta') == false) {
+                var decodedMeta = decodeURIComponent(that.getMetadata('vp_colMeta'));
+                if (decodedMeta != "") {
+                    var colMeta = JSON.parse(decodedMeta);
+                    // add columns as colMeta length
+                    for(var i = 0; i < colMeta.length -1; i++) {
+                        $(that.wrapSelector('#vp_addCol')).trigger('click');
+                    }
+                    // load column data
+                    var colList = $(that.wrapSelector('#vp_colList tr td:not(:last)'));
+                    for (var i = 0; i < colList.length; i++) {
+                        var colTag = $(colList[i]);
+                        colTag.find('.vp-col-list').val(colMeta[i]['vp-col-list']);
+                        colTag.find('.vp-oper-list').val(colMeta[i]['vp-oper-list']);
+                        colTag.find('.vp-condition').val(colMeta[i]['vp-condition']);
+                        colTag.find('.vp-oper-connect').val(colMeta[i]['vp-oper-connect']);
+                    }
+                }
+                that.checkMetaLoaded('vp_colMeta');
+            }
 
             // replace board with now status of board option
             that.replaceBoard();
@@ -605,8 +966,6 @@ define([
         
         // init
         $(this.wrapSelector('#vp_varApiList')).html('<ul class="vp-var-api-list"></ul>');
-        $(this.wrapSelector('#vp_varApiSearch')).val('');
-        $(this.wrapSelector('#vp_varApiFuncId')).val('');
         $(this.wrapSelector('#vp_varApiSearch')).autocomplete('option', 'source', []);
 
         // api list
@@ -657,9 +1016,14 @@ define([
 
         // TODO: 변수 내용 조회
         var boardCode = vpBoard.getCode();
-        if (boardCode == undefined) return "BREAK_RUN"; // 코드 생성 중 오류 발생
+        if (boardCode == undefined) return ""; // 코드 생성 중 오류 발생
         
-        sbCode.appendFormat('{0}', boardCode);
+        var returnCode = $(this.wrapSelector('#vp_returnVariable')).val();
+        if (returnCode != '') {
+            returnCode = returnCode + ' = ';
+        }
+
+        sbCode.appendFormat('{0}{1}', returnCode, boardCode);
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
