@@ -19,7 +19,7 @@ define([
      * html load 콜백. 고유 id 생성하여 부과하며 js 객체 클래스 생성하여 컨테이너로 전달
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
-    var optionLoadCallback = function(callback) {
+    var optionLoadCallback = function(callback, meta) {
         // document.getElementsByTagName("head")[0].appendChild(link);
         // 컨테이너에서 전달된 callback 함수가 존재하면 실행.
         if (typeof(callback) === 'function') {
@@ -31,10 +31,11 @@ define([
                     uuid = vpCommon.getUUID();
                 }
             }
-            $(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM)).find(vpConst.OPTION_PAGE).addClass(uuid);
+            $(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM))).find(vpCommon.formatString(".{0}", vpConst.API_OPTION_PAGE)).addClass(uuid);
 
             // 옵션 객체 생성
             var mpPackage = new MatplotPackage(uuid);
+            mpPackage.metadata = meta;
 
             // 옵션 속성 할당.
             mpPackage.setOptionProp(funcOptProp);
@@ -48,8 +49,8 @@ define([
      * html 로드. 
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
-    var initOption = function(callback) {
-        vpCommon.loadHtml(vpCommon.wrapSelector(vpConst.OPTION_GREEN_ROOM), "pandas/common/commonPandas.html", optionLoadCallback, callback);
+    var initOption = function(callback, meta) {
+        vpCommon.loadHtml(vpCommon.wrapSelector(vpCommon.formatString("#{0}", vpConst.OPTION_GREEN_ROOM)), "pandas/common/commonPandas.html", optionLoadCallback, callback, meta);
     }
 
     /**
@@ -69,7 +70,15 @@ define([
                 }
             ],
             output: [],
-            variable: []
+            variable: [],
+            postfix: [
+                "%matplotlib inline"
+                , ""
+                , "#plt.style.use('fivethirtyeight')"
+                , "#from matplotlib.pylab import rcParams"
+                , "#rcParams['figure.figsize'] = 12, 8"
+                , "#rcParams['axes.grid'] = True"
+            ]
         }
     }
 
@@ -121,18 +130,25 @@ define([
         pdGen.vp_showInterface(this.wrapSelector(''), this.package);
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
-            $(this.wrapSelector('#vp_optionBox')).closest('div.vp-pandas-block').remove();
+            $(this.wrapSelector('#vp_optionBox')).closest('div.vp-accordion-container').remove();
         }
 
         // FIXME: 일단 이름 변경 막기
         $(this.wrapSelector('#i0')).attr('disabled', true);
+
+        // matplotlib 설정값 주석으로 입력 FIXME: 추후엔 postfix/prefix code도 공통generator에서 작업
+        var postCode = new sb.StringBuilder();
+        this.package.postfix.forEach(code => {
+            postCode.appendLine(code);
+        })
+        $(this.wrapSelector('#vp_postfixBox textarea')).val(postCode.toString());
     };
 
     /**
      * 코드 생성
      * @param {boolean} exec 실행여부
      */
-    MatplotPackage.prototype.generateCode = function(exec) {
+    MatplotPackage.prototype.generateCode = function(addCell, exec) {
         if (!this.optionValidation()) return;
 
         try {
@@ -160,12 +176,14 @@ define([
             }
 
             // 코드 추가 및 실행
-            this.cellExecute(sbCode.toString(), exec);
+            if (addCell) this.cellExecute(sbCode.toString(), exec);
         } catch (exmsg) {
             // 에러 표시
             vpCommon.renderAlertModal(exmsg);
             return "BREAK_RUN"; // 코드 생성 중 오류 발생
         }
+
+        return sbCode.toString();
     }
 
     return {
