@@ -1,7 +1,14 @@
 define ([
     'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function( NumpyPageRender ) {
 
+    , 'nbextensions/visualpython/src/numpy/constData'
+], function( NumpyPageRender
+            , constData ) {
+    const { STATE_paramOneArray
+            , STATE_paramTwoArray
+            , STATE_paramThreeArray
+            , STATE_paramScalar
+            , STATE_paramVariable } = constData;
     'use strict';
     /**
      * @class NpArrayPageRender
@@ -28,10 +35,8 @@ define ([
         this.rootTagSelector = tagSelector || this.getMainPageSelector();
         var numpyPageRenderThis = this;
         var numpyStateGenerator = numpyPageRenderThis.getStateGenerator();
-  
 
-        // state의 paramData 객체의 키값을 string 배열로 리턴
-        var stateParamNameStrArray = Object.keys(numpyStateGenerator.getState('paramData'));
+
         var tabTitle = 'Input Parameter';
         const { PARAM_ONE_ARRAY_EDITOR_TYPE, PARAM_TWO_ARRAY_EDITOR_TYPE,
                 PARAM_THREE_ARRAY_EDITOR_TYPE, PARAM_INPUT_EDITOR_TYPE } = this.numpyEnumRenderEditorFuncType;
@@ -42,7 +47,7 @@ define ([
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_ONE_ARRAY_EDITOR_TYPE
-                    , stateParamNameStrOrStrArray: stateParamNameStrArray[0]
+                    , stateParamNameStrOrStrArray: STATE_paramOneArray
                 }
             },
             {
@@ -51,7 +56,7 @@ define ([
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_TWO_ARRAY_EDITOR_TYPE
-                    , stateParamNameStrOrStrArray: stateParamNameStrArray[1]
+                    , stateParamNameStrOrStrArray: STATE_paramTwoArray
                 }
             },
             {
@@ -60,7 +65,7 @@ define ([
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_THREE_ARRAY_EDITOR_TYPE
-                    , stateParamNameStrOrStrArray: stateParamNameStrArray[2]
+                    , stateParamNameStrOrStrArray: STATE_paramThreeArray
                 }
             },
             {
@@ -69,7 +74,7 @@ define ([
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
-                    , stateParamNameStrOrStrArray: [ stateParamNameStrArray[3] ]
+                    , stateParamNameStrOrStrArray: [ STATE_paramScalar ]
                     , paramNameStrArray: ['스칼라 값']
                     , placeHolderArray: ['숫자 입력']
                 }
@@ -81,7 +86,7 @@ define ([
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
-                    , stateParamNameStrOrStrArray: [ stateParamNameStrArray[4] ]
+                    , stateParamNameStrOrStrArray: [ STATE_paramVariable ]
                     , paramNameStrArray: ['변수']
                     , placeHolderArray: ['변수 입력']
                 }
