@@ -1,13 +1,8 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
-    , 'nbextensions/visualpython/src/common/constant_numpy'
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function( requirejs, vpCommon, 
-             vpNumpyConst, NumpyPageRender ) {
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
 
-    "use strict";
+    'use strict';
     /**
      * @class NpSwapaxesCodeRender
      * @constructor
@@ -45,14 +40,14 @@ define ([
         var bindFuncData = {
             numpyPageRenderThis: numpyPageRenderThis
             , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
-            , stateParamNameStrOrStrArray: ["paramAxis1", "paramAxis2"] 
-            , paramNameStrArray: ["Axis1","Axis2"]
-            , placeHolderArray: ["숫자 입력", "숫자 입력"]
+            , stateParamNameStrOrStrArray: ['paramAxis1', 'paramAxis2'] 
+            , paramNameStrArray: ['Axis1','Axis2']
+            , placeHolderArray: ['숫자 입력', '숫자 입력']
         }
 
         /** 옵션 창 */
         this.renderAdditionalOptionContainer();
-        this.renderInputIndexValueBlock("Input Axis", bindFuncData);
+        this.renderInputIndexValueBlock('Input Axis', bindFuncData);
         this.renderReturnVarBlock();
 
         /** userOption 창 */
