@@ -54,7 +54,9 @@ define ([
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
-                    , stateParamNameStrOrStrArray: [ stateParamNameStrArray[2], stateParamNameStrArray[3], stateParamNameStrArray[4]]
+                    , stateParamNameStrOrStrArray: [ stateParamNameStrArray[2], 
+                                                     stateParamNameStrArray[3], 
+                                                     stateParamNameStrArray[4]]
                     , paramNameStrArray: ['Axis0','Axis1','Axis2']
                     , placeHolderArray: ['숫자 입력', '숫자 입력', '숫자 입력']
                 }
