@@ -1,13 +1,8 @@
 define ([
-    'require'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    // numpy 패키지를 위한 라이브러리import 
- 
-    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
-], function(requirejs, vpCommon, 
-            NumpyPageRender ) {
+    'nbextensions/visualpython/src/numpy/common/NumpyPageRender/parent/NumpyPageRender'
+], function( NumpyPageRender ) {
 
-    "use strict";
+    'use strict';
     /**
      * @class BinaryArimethicPageRender
      * @constructor
@@ -38,15 +33,15 @@ define ([
         var numpyPageRenderThis = this;
 
         // state의 paramData 객체의 키값을 string 배열로 리턴
-        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState("paramData"));
-        var tabTitle = "Input Parameter";
+        var stateParamNameStrArray = Object.keys(this.numpyStateGenerator.getState('paramData'));
+        var tabTitle = 'Input Parameter';
         const { PARAM_ONE_ARRAY_EDITOR_TYPE, PARAM_TWO_ARRAY_EDITOR_TYPE,
                 PARAM_THREE_ARRAY_EDITOR_TYPE, PARAM_INPUT_EDITOR_TYPE } = this.numpyEnumRenderEditorFuncType;
 
         var tabBlockArray = [
             {
                 tabNumber: 1
-                , btnText: "1D array"
+                , btnText: '1D array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_ONE_ARRAY_EDITOR_TYPE
@@ -55,7 +50,7 @@ define ([
             },
             {
                 tabNumber: 2
-                , btnText: "2D array"
+                , btnText: '2D array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_TWO_ARRAY_EDITOR_TYPE
@@ -64,7 +59,7 @@ define ([
             },
             {
                 tabNumber: 3
-                , btnText: "3D array"
+                , btnText: '3D array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_THREE_ARRAY_EDITOR_TYPE
@@ -73,29 +68,29 @@ define ([
             },
             {
                 tabNumber: 4
-                , btnText: "scalar value"
+                , btnText: 'scalar value'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[3] ]
-                    , paramNameStrArray: ["스칼라 값"]
-                    , placeHolderArray: ["숫자 입력"]
+                    , paramNameStrArray: ['스칼라 값']
+                    , placeHolderArray: ['숫자 입력']
                 }
             },
             {
                 tabNumber: 5
-                , btnText: "param Variable"
+                , btnText: 'param Variable'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[4] ]
-                    , paramNameStrArray: ["변수"]
-                    , placeHolderArray: ["변수 입력"]
+                    , paramNameStrArray: ['변수']
+                    , placeHolderArray: ['변수 입력']
                 }
             }
         ];
         var tabDataObj = {
-            tabTitle: "First Input Parameter",
+            tabTitle: 'First Input Parameter',
             tabBlockArray,
             stateParamOptionName: `paramOption1`
         }
@@ -104,7 +99,7 @@ define ([
         var tabBlockArray2 = [
             {
                 tabNumber: 1
-                , btnText: "1D Array"
+                , btnText: '1D Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_ONE_ARRAY_EDITOR_TYPE
@@ -113,7 +108,7 @@ define ([
             },
             {
                 tabNumber: 2
-                , btnText: "2D Array"
+                , btnText: '2D Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_TWO_ARRAY_EDITOR_TYPE
@@ -122,7 +117,7 @@ define ([
             },
             {
                 tabNumber: 3
-                , btnText: "3D Array"
+                , btnText: '3D Array'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_THREE_ARRAY_EDITOR_TYPE
@@ -131,30 +126,30 @@ define ([
             },
             {
                 tabNumber: 4
-                , btnText: "Scalar Value"
+                , btnText: 'Scalar Value'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[8] ]
-                    , paramNameStrArray: ["스칼라 값"]
-                    , placeHolderArray: ["숫자 입력"]
+                    , paramNameStrArray: ['스칼라 값']
+                    , placeHolderArray: ['숫자 입력']
                 }
             },
             {
                 tabNumber: 5
-                , btnText: "Param Variable"
+                , btnText: 'Param Variable'
                 , bindFuncData: {
                     numpyPageRenderThis: numpyPageRenderThis
                     , numpyPageRenderFuncType: PARAM_INPUT_EDITOR_TYPE
                     , stateParamNameStrOrStrArray: [ stateParamNameStrArray[9] ]
-                    , paramNameStrArray: ["변수"]
-                    , placeHolderArray: ["변수 입력"]
+                    , paramNameStrArray: ['변수']
+                    , placeHolderArray: ['변수 입력']
                     
                 }
             }
         ];
         var tabDataObj2 = {
-            tabTitle: "Second Input Parameter",
+            tabTitle: 'Second Input Parameter',
             tabBlockArray: tabBlockArray2,
             stateParamOptionName: `paramOption2`
         }
