@@ -35,11 +35,11 @@ define ([
                 var narrayBlockIndexDiv = renderDiv({'class': `vp-numpy-style-flex-column-center 
                                                                vp-numpy-style-font-weight-700 
                                                                margin-right-5px`
-                                                     , 'text': `N${j+1}`});
+                                                     , 'text': `Value ${j+1}`});
                 var narrayBlockInput = renderInput({'class': 'vp-numpy-input'
                                                      , 'value': `${stateElement}`
                                                      , 'type': 'text'
-                                                     , 'placeholder': 'Input'});
+                                                     , 'placeholder': 'Value'});
                 var deleteButton = renderButton({'class':'vp-numpy-func_btn'
                                                  , 'text':'x'});
 
