@@ -148,15 +148,15 @@ define ([
             })(i);
         }
 
-        twoarrayDom.parent().find(`.vp-numpy-array-twoarray-row-func_plusbtn-${stateParamName}`).off();
-        twoarrayDom.parent().find(`.vp-numpy-array-twoarray-row-func_plusbtn-${stateParamName}`).remove();
+        twoarrayDom.find(`.vp-numpy-array-twoarray-row-func_plusbtn-${stateParamName}`).off();
+        twoarrayDom.find(`.vp-numpy-array-twoarray-row-func_plusbtn-${stateParamName}`).remove();
         var plusButton = renderButton({'class':`vp-numpy-func_btn vp-numpy-array-twoarray-row-func_plusbtn-${stateParamName}`
                                         , 'style': 'width: 100%; padding: 1rem;'});
         var span = renderSpan({'class': 'vp-multilang'
                                 , 'data_caption_id': 'numpyPlusRow'
                                 , 'text': '+ Row'});
         plusButton.append(span);
-        twoarrayDom.parent().append(plusButton);
+        twoarrayDom.append(plusButton);
 
         // 2차원 배열 행(row) 생성 클릭
         $(plusButton).click( function() {
