@@ -18,16 +18,16 @@ define ([
         var optionPage = $(importPackageThis.wrapSelector(optionPageSelector));
 
         var numpyIndexValueArray = numpyPageRendererThis.numpyIndexValueArray;
-        var indexBlock = $(`<div class='vp-numpy-option-block 
-                                        vp-numpy-${uuid}-block vp-spread' 
+        var indexBlock = $(`<tr class='vp-numpy-option-block 
+                                        vp-numpy-${uuid}-block' 
                                 id='vp_blockArea'>
 
-                            </div>`);
+                            </tr>`);
                  
         optionPage.append(indexBlock);
-        var numpyBlock = $(importPackageThis.wrapSelector(`.vp-numpy-${uuid}-block`));
-        var flexRow = $(`<div class='vp-numpy-style-flex-row'></div>`);
-        numpyBlock.append(flexRow);
+        // var numpyBlock = $(importPackageThis.wrapSelector(`.vp-numpy-${uuid}-block`));
+        // var flexRow = $(`<div class='vp-numpy-style-flex-row'></div>`);
+        // numpyBlock.append(flexRow);
 
         /**
          *  파라미터 타입에 따라 처리하는 경우의 수가 달라진다.
@@ -44,22 +44,17 @@ define ([
             for(var i = 0; i < stateParamNameOrSelectValueDataArray.length; i++){
                 (function(j) {
                     var uuid2 = vpCommon.getUUID();
-                    var numpySelect = $(`<table style='width: 100%;'>
-                                            <tr>
-                                                <td style='width: 40%;'>
-                                                    <label class='vp-multilang' data-caption-id='selectIndexValue'
-                                                            style='margin-bottom: 0px;'> 
-                                                        ${title}
-                                                    </label>
+                    var numpySelect = $(` 
+                                                <td>
+                                                    ${title}
                                                 </td>
                                                     
                                                 <td>
                                                     <select class='vp-numpy-select-${uuid2}' 
                                                             id='vp_numpySelect'></select>
                                                 </td>
-                                            </tr>
-                                        </table>`);
-                    flexRow.append(numpySelect);
+                                            `);
+                    indexBlock.append(numpySelect);
 
                     /**
                      *  select 태그 배열에 옵션 데이터 리스트를 <option>태그에 담아 렌더링한다
@@ -87,21 +82,16 @@ define ([
              *  select 태그에 옵션 데이터 리스트를 <option>태그에 담아 렌더링한다
             */
                                         
-            var numpySelect = $(`<table style='width: 100%;'>
-                                    <tr>
-                                        <td style='width: 40%;'>
-                                            <label class='vp-multilang' data-caption-id='selectIndexValue'
-                                                    style='margin-bottom: 0px;'> 
-                                                ${title}
-                                            </label>
-                                        </td>
+            var numpySelect = $(`
+                                        <th>
+                                            ${title}
+                                        </th>
                                             
                                         <td>
                                             <select class='vp-numpy-select' id='vp_numpySelect'></select>
                                         </td>
-                                    </tr>
-                                </table>`);
-            numpyBlock.append(numpySelect);
+                                    `);
+            indexBlock.append(numpySelect);
             numpyIndexValueArray.forEach((element) => {
                 $(importPackageThis.wrapSelector('#vp_numpySelect')).append(`<option value='${element}'> ${element}</option>`)
             });
