@@ -11,13 +11,19 @@ define([
     , 'nbextensions/visualpython/src/numpy/api/numpyRouteMapApi'
     , 'nbextensions/visualpython/src/numpy/api/numpyValidatorApi'
     , 'nbextensions/visualpython/src/numpy/constData'
+
+    , 'nbextensions/visualpython/src/numpy/common/NumpyCodeGenerator/child/functionList/NpCopyCodeGenerator'
+    , 'nbextensions/visualpython/src/numpy/common/NumpyPageRender/child/functionList/NpCopyPageRender'
+    , 'nbextensions/visualpython/src/numpy/common/NumpyStateGenerator/parent/NumpyStateGenerator'
 ], function ( requirejs, $, vpCommon, vpConst, vpFuncJS, 
-              vpNumpyConst, numpyStateApi, numpyRouteMapApi, numpyValidatorApi, numpyConstData ) {
+              vpNumpyConst, numpyStateApi, numpyRouteMapApi, numpyValidatorApi, numpyConstData ,
+              NumpyCodeGenerator, NumpyPageRender, 
+              NumpyStateGenerator ) {
     // 옵션 속성 
     const funcOptProp = {
         stepCount : 1
-        , funcName : "np.copy"
-        , funcID : "JY23"  // TODO: ID 규칙 생성 필요
+        , funcName : "np_copy"
+        , funcID : "np_copy"  // TODO: ID 규칙 생성 필요
     }
 
     /** numpy에서 사용하는 constData */
@@ -26,11 +32,12 @@ define([
     // FuncId에 맞는 FuncData를 맵핑하는 api
     const { newMapFuncIdToNumpyFuncData, mapFuncIdToHtmlUrlPath } = numpyRouteMapApi;
     const { validateNumpyState } = numpyValidatorApi;
+
     /**
      * html load 콜백. 고유 id 생성하여 부과하며 js 객체 클래스 생성하여 컨테이너로 전달
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
      */
-    var optionLoadCallback = function(callback) {
+    var optionLoadCallback = function(callback, meta) {
         // document.getElementsByTagName("head")[0].appendChild(link);
         // 컨테이너에서 전달된 callback 함수가 존재하면 실행.
         if (typeof(callback) === 'function') {
@@ -45,6 +52,7 @@ define([
             $(vpCommon.wrapSelector(`${VP_ID_PREFIX}${vpConst.OPTION_GREEN_ROOM}`)).find(`${VP_CLASS_PREFIX}${vpConst.API_OPTION_PAGE}`).addClass(uuid);
             // 옵션 객체 생성
             var ipImport = new ImportPackage(uuid);
+            ipImport.metadata = meta;
             // 옵션 속성 할당.
             ipImport.setOptionProp(funcOptProp);
             // html 설정.
@@ -52,13 +60,14 @@ define([
             callback(ipImport);  // 공통 객체를 callback 인자로 전달
         }
     }
+
     /**
      * html 로드. 
      * @param {function} callback 호출자(컨테이너) 의 콜백함수
-    */
-    var initOption = function(callback) {
-        var htmlUrlPath  = mapFuncIdToHtmlUrlPath(funcOptProp.funcID);
-        vpCommon.loadHtml(vpCommon.wrapSelector(`${VP_ID_PREFIX}${vpConst.OPTION_GREEN_ROOM}`), htmlUrlPath, optionLoadCallback, callback);
+     */
+    var initOption = function(callback, meta) {
+        var htmlUrlPath = vpNumpyConst.STR_NUMPY_HTML_URL_PATH;
+        vpCommon.loadHtml(vpCommon.wrapSelector(`${VP_ID_PREFIX}${vpConst.OPTION_GREEN_ROOM}`), htmlUrlPath, optionLoadCallback, callback, meta);
     }
 
     /**
@@ -71,6 +80,15 @@ define([
         // this.numpyCodeValidator // numpyCodeValidator은 코드 실행 전 입력된 state 값을 검증
         this.numpyPageRender // numpyPageRender는 동적 html을 index.html에 렌더링
         this.numpyStateGenerator // numpyStateGenerator는 state를 생성, 변경 
+        this.state = {
+            paramData:{
+                paramVariable: ''
+            }
+            , returnVariable: ''
+            , isReturnVariable: false
+            , makedCodeStr: ''
+        }
+        this.metadata;
     }
 
     /**
@@ -91,19 +109,29 @@ define([
         * html 내부 binding 처리
     */
     ImportPackage.prototype.initHtml = function() {
-        var { numpyCodeGenerator
-            // , numpyCodeValidator
-            , numpyPageRender
-            , numpyStateGenerator } = newMapFuncIdToNumpyFuncData(funcOptProp.funcID, funcOptProp.funcName);
-        this.numpyCodeGenerator = numpyCodeGenerator;
-        // this.numpyCodeValidator = numpyCodeValidator;
-        this.numpyPageRender = numpyPageRender;
-        this.numpyStateGenerator = numpyStateGenerator;
+       
+        this.numpyCodeGenerator = new NumpyCodeGenerator();
+        this.numpyPageRender = new NumpyPageRender( vpNumpyConst.NUMPY_OPTION_OBJ);
+        this.numpyStateGenerator = new NumpyStateGenerator();
 
+        this.numpyStateGenerator.setImportPackageThis(this);
+        this.numpyStateGenerator.makeState(this.state);
+        this.numpyCodeGenerator.setStateGenerator(this.numpyStateGenerator);
+        this.numpyPageRender.setStateGenerator(this.numpyStateGenerator);
+ 
         //importPackageThis와 동적 html 태그들을 index.html에 렌더링 
         this.numpyPageRender.setImportPackageThis(this);
-        this.numpyPageRender.pageRender();
+  
+        if (this.metadata) {
+            this.numpyStateGenerator.setMetadata(this.metadata);
+            this.numpyPageRender.pageRender();
+        } else {
+            this.numpyPageRender.pageRender();
+            // this.numpyStateGenerator.setMetadata(this.metadata);
+        }
+        this.numpyStateGenerator.setAPIBlockMetadataHandler();
         this.numpyPageRender.renderFuncName(funcOptProp.funcName);
+
         // import load css
         this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + vpNumpyConst.NUMPY_BASE_CSS_PATH);
     }
@@ -116,18 +144,28 @@ define([
     }
     
     /**
-        * 코드 생성
-        * @param {boolean} exec 실행여부
-        */
-    ImportPackage.prototype.generateCode = function(exec) {
-        // validate code 
+     * 코드 생성
+     * @param {boolean} exec 실행여부
+     */
+    ImportPackage.prototype.generateCode = function(addCell, exec) {
+        /** 코드 검사 validate code */
         if (!this.optionValidation()) return;
-        // make code
+
+        /** 코드 생성 make code */
         this.numpyCodeGenerator.makeCode();
         var result = this.numpyCodeGenerator.getCodeAndClear();
         if (result == null) return "BREAK_RUN"; // 코드 생성 중 오류 발생
-        // execute code
+
+      
+        /** 코드 add만 실행 */
+        if ( !addCell ) {
+            this.numpyStateGenerator.saveMetadata(this.metadata);
+            return result;
+        }
+
+        /** 코드 run 실행 */
         this.cellExecute(result, exec);
+        this.numpyStateGenerator.saveMetadata(this.metadata);
     }
 
     return {
