@@ -7,7 +7,8 @@ define([
     , 'nbextensions/visualpython/src/common/vpFuncJS'
     , 'nbextensions/visualpython/src/pandas/common/commonPandas'
     , 'nbextensions/visualpython/src/common/vpMakeDom'
-], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, vpMakeDom) {
+    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
+], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, vpMakeDom, vpSuggestInputText) {
     // FIXME: cell metadata test / 전역으로 말고 불러오기/덮어쓰기로 수정
     var _VP_CODEMD = {};
 
@@ -109,7 +110,7 @@ define([
         switch (obj.component) {
             case 'bool_checkbox':
                 // FIXME: True False select box
-                var select = $(`<select id=${obj.name}><option value="">Default</option></select>`);
+                var select = $(`<select id="${obj.name}" class="vp-select"><option value="">Default</option></select>`);
                 select.append($('<option value="True">True</option>'))
                     .append($('<option value="False">False</option>'));
                 $(tblInput).append(select);
@@ -117,7 +118,7 @@ define([
             case 'option_select':
                 var optSlct = document.createElement('select');
                 $(optSlct).attr({
-                    'class':'option-select',
+                    'class':'vp-select option-select',
                     'id':obj.name
                 });
                 // if required, no default option
@@ -157,7 +158,7 @@ define([
                 var tag = document.createElement('select');
                 $(tag).attr({
                     'id': obj.name,
-                    'class': 'var-select'
+                    'class': 'vp-select var-select'
                 });
                 vp_generateVarSelect(tag, obj.var_type, obj.value);
                 tblInput.appendChild(tag);
@@ -167,7 +168,7 @@ define([
                 var tag = document.createElement('select');
                 $(tag).attr({
                     'id': obj.name,
-                    'class': 'var-multi',
+                    'class': 'vp-select var-multi',
                     // 다중 선택 가능하게 설정
                     'multiple': true
                 });
@@ -200,7 +201,7 @@ define([
                 // FIXME: use makedom
                 var input = vpMakeDom.renderInput({
                     'type':'text',
-                    'class':'input-single',
+                    'class':'vp-input input-single',
                     'id':obj.name,
                     'placeholder':(obj.placeholder==undefined?'':obj.placeholder),
                     'value':(obj.default==undefined?'':obj.default),
@@ -249,7 +250,8 @@ define([
                     var option = document.createElement('option');
                     $(option).attr({
                         'value':listVar.varName,
-                        'text':listVar.varName
+                        'text':listVar.varName,
+                        'data-type':listVar.varType
                     });
                     // cell metadata test : defaultValue에 따라서 selected 적용
                     if (listVar.varName == defaultValue) {
@@ -265,6 +267,9 @@ define([
             if (classname == 'var-multi') {
                 $(tag).val(defaultValue);
             }
+
+            // trigger change
+            $(tag).trigger('change');
         });
     }
 
@@ -365,12 +370,12 @@ define([
                 if (input == obj.default) break;
                 value = input;
                 break;
-            case 'bool_checkbox':
-                var input = $(vp_wrapSelector(pageId, "input[name='"+obj.name+"']")).is(":checked");
-                // default 값과 동일하다면 굳이 옵션에 넣어주지 않는다
-                if (input == obj.default) break;
-                value = input == true?'True':'False';
-                break;
+            // case 'bool_checkbox':
+            //     var input = $(vp_wrapSelector(pageId, "input[name='"+obj.name+"']")).is(":checked");
+            //     // default 값과 동일하다면 굳이 옵션에 넣어주지 않는다
+            //     if (input == obj.default) break;
+            //     value = input == true?'True':'False';
+            //     break;
             case 'option_checkbox':
                 var checked = $(vp_wrapSelector(pageId, "input[name='"+obj.name+"']:checked")).val();
 
@@ -446,7 +451,7 @@ define([
                     // _VP_CODEMD.input[i].value = val;
                     // val type 에 따라 다른 형식 적용
                     if (v.type == 'text') {
-                        val = '"'+val+'"';
+                        val = "'"+val+"'";
                     } else if (v.type == 'list') {
                         val = '['+val+']';
                     }
@@ -470,7 +475,7 @@ define([
                     // _VP_CODEMD.variable[i].value = val;
                     // val type 에 따라 다른 형식 적용
                     if (v.type == 'text') {
-                        val = '"'+val+'"';
+                        val = "'"+val+"'";
                     } else if (v.type == 'list') {
                         val = '['+val+']';
                     }
@@ -497,7 +502,7 @@ define([
                     // _VP_CODEMD.output[i].value = val;
                     // val type 에 따라 다른 형식 적용
                     if (v.type == 'text') {
-                        val = '"'+val+'"';
+                        val = "'"+val+"'";
                     } else if (v.type == 'list') {
                         val = '['+val+']';
                     }
@@ -508,7 +513,7 @@ define([
             // 추가 사용자 옵션
             code = code.split('${etc}').join(etcOptions);
 
-            // () 함수 파라미터 공간에 input 없을 경우 (, %v) 와 같은 형태로 출력되는 것 방지
+            // () 함수 파라미터 공간에 input 없을 경우 (, ${v}) 와 같은 형태로 출력되는 것 방지
             code = code.split('(, ').join('(');
 
             // show_result : 마지막에 결과값 보여주기
@@ -526,11 +531,65 @@ define([
         return code;
     }
 
+    /**
+     * Bind columns source function
+     * @param {object} pageThis 
+     * @param {object} target 
+     * @param {array} columnInputIdList 
+     * Usage : 
+     *  $(document).on('change', this.wrapSelector('#dataframe_tag_id'), function() {
+     *      pdGen.vp_bindColumnSource(that, this, ['column_input_id']);
+     *  });
+     */
+    var vp_bindColumnSource = function(pageThis, target, columnInputIdList) {
+        var varName = $(target).val();
+        var varType = $(target).find(':selected').data('type');
+
+        if (varType != 'DataFrame') {
+            // reset with no source
+            columnInputIdList && columnInputIdList.forEach(columnInputId => {
+                var suggestInputX = new vpSuggestInputText.vpSuggestInputText();
+                suggestInputX.setComponentID(columnInputId);
+                suggestInputX.addClass('vp-input');
+                suggestInputX.setNormalFilter(false);
+                $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
+                    return suggestInputX.toTagString();
+                });
+            });
+            return ;
+        }
+
+        var code = new sb.StringBuilder();
+        code.appendLine('import json');
+        code.appendFormat(`print(json.dumps([ { "value": ("'" + c + "'") if type(c).__name__ == 'str' else c, "label": c, "dtype": str({0}[c].dtype), "array": str({1}[c].array) } for c in list({2}.columns) ]))`
+                        , varName, varName, varName);
+        // get result and show on detail box
+        pageThis.kernelExecute(code.toString(), function(result) {
+            var varResult = JSON.parse(result);
+
+            if (varResult.length > 0) {
+                // columns using suggestInput
+                columnInputIdList && columnInputIdList.forEach(columnInputId => {
+                    var suggestInputX = new vpSuggestInputText.vpSuggestInputText();
+                    suggestInputX.setComponentID(columnInputId);
+                    suggestInputX.addClass('vp-input');
+                    suggestInputX.setPlaceholder("column name");
+                    suggestInputX.setSuggestList(function() { return varResult; }); //FIXME:
+                    suggestInputX.setNormalFilter(false);
+                    $(pageThis.wrapSelector('#' + columnInputId)).replaceWith(function() {
+                        return suggestInputX.toTagString();
+                    });
+                });
+            }
+        });
+    }
+
     return {
         vp_showInterface: vp_showInterface,
         vp_codeGenerator: vp_codeGenerator,
         vp_generateVarSelect: vp_generateVarSelect,
         vp_searchVarList: vp_searchVarList,
-        vp_getTagValue: vp_getTagValue
+        vp_getTagValue: vp_getTagValue,
+        vp_bindColumnSource: vp_bindColumnSource
     };
 });
\ No newline at end of file
