@@ -122,7 +122,7 @@ define([
         pdGen.vp_showInterface(this.wrapSelector(''), this.package);
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
-            $(this.wrapSelector('#vp_optionBox')).closest('div.vp-pandas-block').remove();
+            $(this.wrapSelector('#vp_optionBox')).closest('div.vp-accordion-container').remove();
         }
 
         // FIXME: 일단 이름 변경 막기
