@@ -7,7 +7,8 @@ define([
     , 'nbextensions/visualpython/src/common/vpFuncJS'
     , 'nbextensions/visualpython/src/pandas/common/commonPandas'
     , 'nbextensions/visualpython/src/pandas/common/pandasGenerator'
-], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, pdGen) {
+    , 'nbextensions/visualpython/src/common/component/vpSuggestInputText'
+], function (requirejs, $, vpCommon, vpConst, sb, vpFuncJS, libPandas, pdGen, vpSuggestInputText) {
     // 옵션 속성
     const funcOptProp = {
         stepCount : 1
@@ -106,16 +107,15 @@ define([
      */
     PandasPackage.prototype.initHtml = function() {
         this.showFunctionTitle();
+        
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/plot.css");
 
+        this.bindOptionEvents();
         this.bindOptions();
         this.bindKindSelector();
         this.bindCmapSelector();
         this.bindOptionDivider(14);
-        this.bindOptionEvents();
-        this.bindUserOption();
-
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/plot.css");
     }
 
     /**
@@ -135,6 +135,16 @@ define([
         var kindSelector = this.wrapSelector('#kind');
         $(kindSelector).closest('tr').hide();
 
+        // 메타데이터로 차트유형 선택
+        var plotType = 'line';
+        if (this.metadata != undefined && this.metadata.options != undefined) {
+            plotType = this.metadata.options.filter(o => o.id == 'kind')[0].value;
+        }
+
+        // 차트 선택
+        $(kindSelector).val(plotType);
+        $(this.wrapSelector(`#vp_plotKind .vp-plot-item[data-kind="${plotType}"]`)).addClass('selected');
+
         // 유형 선택 이벤트
         $(this.wrapSelector('.vp-plot-item')).click(function() {
             // 선택한 플롯 유형 박스 표시
@@ -167,13 +177,13 @@ define([
                 if (idx > -1) {
                     that.package.variable[idx].required = true;
                     // 라벨 필수 입력 표시
-                    $(that.wrapSelector('#x')).closest('tr').find('label').text("* " + that.package.variable[idx].label);
+                    $(that.wrapSelector('#x')).closest('tr').find('label').text(`* ${that.package.variable[idx].label}(${that.package.variable[idx].name})`);
                 }
                 var idy = that.package.variable.findIndex(function(item) {return item.name === 'y'});
                 if (idy > -1) {
                     that.package.variable[idy].required = true;
                     // 라벨 필수 입력 표시
-                    $(that.wrapSelector('#y')).closest('tr').find('label').text("* " + that.package.variable[idy].label);
+                    $(that.wrapSelector('#y')).closest('tr').find('label').text(`* ${that.package.variable[idy].label}(${that.package.variable[idy].name})`);
                 }
             } else {
                 that.package = libPandas._PANDAS_FUNCTION[funcOptProp.libID];
@@ -181,11 +191,11 @@ define([
                 // 라벨 재정비
                 var idx = that.package.variable.findIndex(function(item) {return item.name === 'x'});
                 if (idx > -1) {
-                    $(that.wrapSelector('#x')).closest('tr').find('label').text(that.package.variable[idx].label);
+                    $(that.wrapSelector('#x')).closest('tr').find('label').text(`${that.package.variable[idx].label}(${that.package.variable[idx].name})`);
                 }
                 var idy = that.package.variable.findIndex(function(item) {return item.name === 'y'});
                 if (idy > -1) {
-                    $(that.wrapSelector('#y')).closest('tr').find('label').text(that.package.variable[idy].label);
+                    $(that.wrapSelector('#y')).closest('tr').find('label').text(`${that.package.variable[idy].label}(${that.package.variable[idy].name})`);
                 }
             }
         });
@@ -215,7 +225,7 @@ define([
             var url = Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.RESOURCE_PATH + 'pandas/cmap/' + ctype + '.JPG';
             $(divColor).css({
                 'background-image' : 'url(' + url + ')'
-            })
+            });
 
             var selectedCmap = this.wrapSelector('#vp_selectedCmap');
 
@@ -246,14 +256,19 @@ define([
      * @param {number} div1Count 분리할 기준 숫자 (숫자 기준으로 이후 항목들 분리) 
      */
     PandasPackage.prototype.bindOptionDivider = function(div1Count) {
-        var option2 = $(this.wrapSelector('#vp_optionBox table tr')).filter(':gt(' + div1Count + ')');
-        $(this.wrapSelector('#vp_optionBox2 table')).append(option2);
+        var option2 = $(this.wrapSelector('#vp_optionBox table tbody tr')).filter(':gt(2):lt(' + (div1Count) + ')');
+        $(this.wrapSelector('#vp_graphicsOptionBox table tbody')).append(option2);
+
+        // useroption to the end
+        $(this.wrapSelector('#vp_optionBox table tbody')).append($(this.wrapSelector('#vp_optionBox table tbody tr:nth-child(2)')));
     }
 
     /**
      * 옵션 변경에 따른 이벤트 등록
      */
     PandasPackage.prototype.bindOptionEvents = function() {
+        var that = this;
+
         // 서브플롯 선택에 따라 layout 옵션 show/hide
         var optLayout = this.wrapSelector('#layout');
         $(optLayout).closest('tr').hide();
@@ -266,46 +281,11 @@ define([
                 $(optLayout).closest('tr').hide();
             }
         });
-    }
 
-    /**
-     * 사용자 옵션 추가 페이지 이벤트
-     */
-    PandasPackage.prototype.bindUserOption = function() {
-        var that = this;
-        $(this.wrapSelector('#vp_addOption')).click(function() {
-            // 옵션 추가
-            var tagTr = document.createElement('tr');
-            var tagTdKey = document.createElement('td');
-            var tagTdValue = document.createElement('td');
-            var tagInputKey = document.createElement('input');
-            $(tagInputKey).attr({
-                type: 'text'
-            });
-            var tagInputValue = document.createElement('input');
-            $(tagInputValue).attr({
-                type: 'text'
-            });
-
-            var tagTdDel = document.createElement('td');
-            var tagBtnDel = document.createElement('input');
-            $(tagBtnDel).attr({
-                type: 'button',
-                value: 'X'
-            });
-            $(tagBtnDel).click(function() {
-                // X 버튼과 동일한 행 삭제
-                $(this).closest('tr').remove();
-            });
-            
-            $(tagTdKey).append(tagInputKey);
-            $(tagTdValue).append(tagInputValue);
-            $(tagTdDel).append(tagBtnDel);
-            $(tagTr).append(tagTdKey);
-            $(tagTr).append(tagTdValue);
-            $(tagTr).append(tagTdDel);
-
-            $(that.wrapSelector('#vp_userOption table tr:last')).before(tagTr);
+        // on dataframe change
+        $(document).on('change', this.wrapSelector('#i0'), function() {
+            // dataframe columns search
+            pdGen.vp_bindColumnSource(that, this, ['x', 'y']);
         });
     }
 
@@ -315,10 +295,9 @@ define([
     PandasPackage.prototype.bindOptions = function() {
         // HTML 구성
         pdGen.vp_showInterface(this.wrapSelector(''), this.package);
-        // if it has no additional options, remove that box
-        if (this.package.variable == undefined || this.package.variable.length <= 0) {
-            $(this.wrapSelector('#vp_optionBox')).closest('div.vp-pandas-block').remove();
-        }
+
+        $(this.wrapSelector('#x')).closest('tr').insertBefore('#vp_inputOutputBox tbody tr:last');
+        $(this.wrapSelector('#y')).closest('tr').insertBefore('#vp_inputOutputBox tbody tr:last');
     };
 
     /**
@@ -339,18 +318,28 @@ define([
 
             // 사용자 옵션 설정값 가져오기
             var userOption = new sb.StringBuilder();
-            $(this.wrapSelector('#vp_userOption table tr:gt(0):not(:last)')).each(function() {
-                var key = $(this).find('td:nth-child(1) input').val();
-                var val = $(this).find('td:nth-child(2) input').val();
-                if (key != '' && val != '') {
-                    userOption.appendFormat(', {0}={1}', key, val);
-                } else {
-                    throw '사용자 옵션 키/값을 입력하거나 삭제해 주세요.';
-                }
-            });
+            // $(this.wrapSelector('#vp_userOptionBox table tbody tr:gt(0):not(:last)')).each(function() {
+            //     var key = $(this).find('td:nth-child(1) input').val();
+            //     var val = $(this).find('td:nth-child(2) input').val();
+            //     if (key != '' && val != '') {
+            //         userOption.appendFormat(', {0}={1}', key, val);
+            //     } else {
+            //         throw '사용자 옵션 키/값을 입력하거나 삭제해 주세요.';
+            //     }
+            // });
+
+            var package = JSON.parse(JSON.stringify(this.package));
+
+            var userOptVal = $(this.wrapSelector('#vp_userOption')).val();
+            if (userOptVal != '') {
+                package.variable.push({name: 'vp_userOption', value: userOptVal});
+                userOption.appendFormat(', {0}', userOptVal);
+            }
+
+            this.package = package;
 
             // 코드 생성
-            var result = pdGen.vp_codeGenerator(this.uuid, this.package, userOption.toString());
+            var result = pdGen.vp_codeGenerator(this.uuid, package, userOption.toString());
             if (result == null) return "BREAK_RUN"; // 코드 생성 중 오류 발생
             sbCode.append(result);
 
