@@ -340,6 +340,13 @@
         $(document).on("blur", vpCommon.wrapSelector("input[type='text']"), function() {
             Jupyter.notebook.keyboard_manager.enable();
         });
+        // minju: hotkey 제어 input number 인 경우 포커스를 가지면 핫키 막고 잃으면 핫키 허용
+        $(document).on("focus", vpCommon.wrapSelector("input[type='number']"), function() {
+            Jupyter.notebook.keyboard_manager.disable();
+        });
+        $(document).on("blur", vpCommon.wrapSelector("input[type='number']"), function() {
+            Jupyter.notebook.keyboard_manager.enable();
+        });
         // minju: prefix & postfix용 - hotkey 제어 textarea 인 경우 포커스를 가지면 핫키 막고 잃으면 핫키 허용
         $(document).on("focus", vpCommon.wrapSelector("textarea"), function() {
             Jupyter.notebook.keyboard_manager.disable();
